@@ -1,5 +1,4 @@
 import unittest
-from numpy import result_type
 
 from pythautomata.automata_definitions.weighted_tomitas_grammars import WeightedTomitasGrammars
 
@@ -10,6 +9,7 @@ from pymodelextractor.teachers.sample_probabilistic_teacher import SampleProbabi
 from pymodelextractor.teachers.pac_probabilistic_teacher import PACProbabilisticTeacher
 from pythautomata.model_comparators.wfa_tolerance_comparison_strategy import WFAToleranceComparator
 
+
 class TestPDFATeachersLStarCol(unittest.TestCase):
 
     def setUp(self):
@@ -18,11 +18,12 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
     def test_tomitas_1(self):
         model = WeightedTomitasGrammars.get_automaton_1()
         teacher1 = PDFATeacher(model, WFAToleranceComparator())
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = 0, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = 0, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = 0, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=0, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=0, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=0, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -34,11 +35,12 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
     def test_tomitas_2(self):
         model = WeightedTomitasGrammars.get_automaton_2()
         teacher1 = PDFATeacher(model, WFAToleranceComparator())
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = 0, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = 0, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = 0, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=0, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=0, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=0, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -51,11 +53,13 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         model = WeightedTomitasGrammars.get_automaton_3()
         tolerance = 0.000001
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance),max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = tolerance, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = tolerance, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = tolerance, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance),
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -67,11 +71,13 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         model = WeightedTomitasGrammars.get_automaton_4()
         tolerance = 0.000001
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = tolerance, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = tolerance, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = tolerance, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -84,11 +90,13 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         model = WeightedTomitasGrammars.get_automaton_5()
         tolerance = 0.000001
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = tolerance, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = tolerance, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = tolerance, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -100,11 +108,13 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         model = WeightedTomitasGrammars.get_automaton_6()
         tolerance = 0.000001
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = tolerance, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = tolerance, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = tolerance, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -116,11 +126,13 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         model = WeightedTomitasGrammars.get_automaton_7()
         tolerance = 0.000001
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
-        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), max_seq_length=20)
-        result1 = self.learner.learn(teacher1, tolerance = tolerance, verbose = True)
-        result2 = self.learner.learn(teacher2, tolerance = tolerance, verbose = True)
-        result3 = self.learner.learn(teacher3, tolerance = tolerance, verbose = True)
+        teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500, 
+                                              max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance), 
+                                           max_seq_length=20)
+        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
+        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
+        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
